Crate kcr_sns_services_k8s_aws

Crate kcr_sns_services_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the sns.services.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

sns.services.k8s.aws/v1alpha1

  • PlatformApplication
  • PlatformEndpoint
  • Subscription
  • Topic

Modules

v1alpha1